==> sphinx_emoji_favicon-0.1.tar.gz: sphinx_emoji_favicon-0.1/setup.py <==
"""
"""

from pathlib import Path

import setuptools

from sphinx_emoji_favicon import version

cwd = Path(__file__).absolute().parent

long_description = (cwd / "README.md").read_text(encoding="utf-8")

install_requires = (cwd / "requirements.txt").read_text(encoding="utf-8").splitlines()

# extras = {}
# extras["test"] = (cwd / "test/requirements.txt").read_text(encoding="utf-8").splitlines()
# extras["docs"] = (cwd / "docs/requirements.txt").read_text(encoding="utf-8").splitlines()
# extras["dev"] = extras["docs"] + extras["test"]


setuptools.setup(
    name="sphinx_emoji_favicon",
    version=version,
    author="DeepPSP",
    author_email="wenh06@gmail.com",
    license="MIT",
    description="A simple sphinx extension to add emoji favicons to html pages.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/DeepPSP/sphinx-emoji-favicon",
    # project_urls={},
    packages=setuptools.find_packages(
        exclude=[
            "docs*",
            "test*",
            "sample*",
        ]
    ),
    # entry_points=,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    install_requires=install_requires,
    # extras_require=extras,
)

==> sphinx_emoji_favicon-0.2.tar.gz: sphinx_emoji_favicon-0.2/setup.py <==
"""
"""

from pathlib import Path

import setuptools

from sphinx_emoji_favicon import version

cwd = Path(__file__).absolute().parent

long_description = (cwd / "README.md").read_text(encoding="utf-8")

install_requires = (cwd / "requirements.txt").read_text(encoding="utf-8").splitlines()

extras = {}
extras["test"] = (cwd / "test/requirements.txt").read_text(encoding="utf-8").splitlines()
# extras["docs"] = (cwd / "docs/requirements.txt").read_text(encoding="utf-8").splitlines()
# extras["dev"] = extras["docs"] + extras["test"]
extras["dev"] = extras["test"]

setuptools.setup(
    name="sphinx_emoji_favicon",
    version=version,
    author="DeepPSP",
    author_email="wenh06@gmail.com",
    license="MIT",
    description="A simple sphinx extension to add emoji favicons to html pages.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/DeepPSP/sphinx-emoji-favicon",
    # project_urls={},
    packages=setuptools.find_packages(
        exclude=[
            "docs*",
            "test*",
            "sample*",
        ]
    ),
    # entry_points=,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    install_requires=install_requires,
    extras_require=extras,
)
